@@ -17,17 +17,17 @@
 #'
 #' @details \itemize{
 #'   \item \sQuote{WMD} is an acronym for \sQuote{with metadata}.
-#'   \item Conceptually, this class treats metadata as arbitrarily nested 
-#'     lists with arbitrary content. Containers of objects that inherit from 
+#'   \item Conceptually, this class treats metadata as arbitrarily nested
+#'     lists with arbitrary content. Containers of objects that inherit from
 #'     this class are not forced to contain the same metadata entries. Problems
 #'     might arise if such data are queried and attempted to be converted to,
-#'     e.g., dataframes because some values might be missing. But metadata can
+#'     e.g., data frames because some values might be missing. But metadata can
 #'     be queried beforehand for the keys as well as the values they contain,
 #'     and other methods support setting, modifying and deleting metadata.
-#'   \item For \code{\link{OPM}} and the other \pkg{opm} classes that use it, 
+#'   \item For \code{\link{OPM}} and the other \pkg{opm} classes that use it,
 #'     \sQuote{metadata} refers to information that, in contrast to, e.g.,
-#'     \code{\link{csv_data}} must be added by the user \strong{after} reading 
-#'     OmniLog(R) CSV files. Metadata might already be present in YAML files 
+#'     \code{\link{csv_data}} must be added by the user \strong{after} reading
+#'     OmniLog(R) CSV files. Metadata might already be present in YAML files
 #'     created by the \pkg{opm} package, however.
 #' }
 #'
@@ -44,30 +44,31 @@ setClass(WMD,
   contains = "VIRTUAL",
   sealed = SEALED
 )
-  
+
 
 ################################################################################
 ################################################################################
 #
 # Getter methods
-#  
+#
+
 
-  
 setGeneric("metadata", function(object, ...) standardGeneric("metadata"))
 #' Get metadata
 #'
 #' Get meta-information stored together with the data.
 #'
 #' @param object \code{\link{WMD}} object.
-#' @param key If \code{NULL} or otherwise empty, return all metadata. If a 
+#' @param key If \code{NULL} or otherwise empty, return all metadata. If a
 #'   non-empty list, treat it as list of keys and return list of corresponding
-#'   metadata values. Here, character vectors of length > 1 can be used to 
+#'   metadata values. Here, character vectors of length > 1 can be used to
 #'   query nested metadata lists. If neither empty nor a list (i.e. usually a
 #'   character or numeric scalar), treat \code{key} as a single list key.
 #' @param exact Logical scalar. Use exact or partial matching of keys? Has no
 #'   effect if \code{key} is empty.
 #' @param strict Logical scalar. Is it an error if a \code{NULL} value results
 #'   from fetching a metadata key?
+#' @param ... Optional arguments passed between the methods.
 #' @return List (empty if metadata were not set or if subselection using
 #'   \code{key} did not result).
 #' @export
@@ -75,24 +76,31 @@ setGeneric("metadata", function(object, ...) standardGeneric("metadata"))
 #' @family metadata-functions
 #' @keywords attribute
 #' @examples
+#'
+#' # 'OPM' method
 #' data(vaas_1)
 #' (x <- metadata(vaas_1, "Strain"))
 #' stopifnot(identical(x, "DSM30083T"))
 #'
-setMethod("metadata", WMD, function(object, key = NULL, exact = TRUE, 
+#' # 'OPMS' method
+#' data(vaas_4)
+#' (x <- metadata(vaas_4, "Strain"))
+#' stopifnot(x == c("DSM18039", "DSM30083T", "DSM1707", "429SC1"))
+#'
+setMethod("metadata", WMD, function(object, key = NULL, exact = TRUE,
     strict = FALSE) {
+  assert_length(exact, strict)
   if (length(key) == 0L)
     return(object@metadata)
   fetch_fun <- if (strict)
     function(key) {
       if (is.null(result <- object@metadata[[key, exact = exact]]))
-        stop("got NULL value when using key ", paste(key, collapse = " -> "))
+        stop(sprintf("got NULL value when using key '%s'", 
+          paste(key, collapse = " -> ")))
       result
     }
   else
-    function(key) {
-      object@metadata[[key, exact = exact]]  
-    }
+    function(key) object@metadata[[key, exact = exact]]
   if (is.list(key)) {
     result <- lapply(key, fetch_fun)
     if (is.null(names(result)))
@@ -107,14 +115,14 @@ setMethod("metadata", WMD, function(object, key = NULL, exact = TRUE,
 ################################################################################
 #
 # Setter methods
-#  
-    
-    
+#
+
+
 setGeneric("metadata<-",
   function(object, key, ..., value) standardGeneric("metadata<-"))
 #' Replace metadata
 #'
-#' Set the meta-information stored together with the data. The 
+#' Set the meta-information stored together with the data. The
 #' \code{\link{OPMS}} methods set the meta-information stored together with the
 #' measurements for all plates at once.
 #'
@@ -125,12 +133,12 @@ setGeneric("metadata<-",
 #' @param key Missing, numeric scalar, character vector, or list.
 #'   If missing, replace all metadata by \code{value}.
 #'   If a numeric scalar, then if positive, prepend \code{value} to
-#'   old metadata. If negative, append \code{value} to old metadata. If zero, 
+#'   old metadata. If negative, append \code{value} to old metadata. If zero,
 #'   replace old metadata entirely by \code{value}.
-#'   If a list, treat it as list of keys; expect \code{value} to be a list 
+#'   If a list, treat it as list of keys; expect \code{value} to be a list
 #'   of corresponding metadata values to be set. Names are replaced by the
 #'   values of either list if they are missing.
-#'   If a character vector, use it as key and set/replace this metadata 
+#'   If a character vector, use it as key and set/replace this metadata
 #'   entry to/by \code{value}. It is an error if \code{key} has zero length.
 #'   If it contains more than one entry, a nested query is done. See \code{[[}
 #'   from the \pkg{base} package for details.
@@ -183,13 +191,13 @@ setGeneric("metadata<-",
 #' stopifnot(length(metadata(copy)) == length(metadata(vaas_1)))
 #' stopifnot(identical(metadata(copy, "Species"), "Gen. sp."))
 #'
-#' # ...but this would delete the entry because nothing would be found in 
+#' # ...but this would delete the entry because nothing would be found in
 #' # 'value'
 #' metadata(copy, list("Species")) <- list(Organism = "E. coli")
 #' stopifnot(length(metadata(copy)) < length(metadata(vaas_1)))
 #' stopifnot(is.null(metadata(copy, "Species")))
 #'
-#' # ...this yields a general mechanism for metadata deletion by providing an 
+#' # ...this yields a general mechanism for metadata deletion by providing an
 #' # empty list as 'value'.
 #'
 #' # WMD+character method
@@ -259,22 +267,22 @@ setMethod("metadata<-", c(WMD, "character", "ANY"), function(object, key,
 ################################################################################
 #
 # Infix operators
-#  
+#
 
 
 setGeneric("%k%", function(x, table) standardGeneric("%k%"))
 #' Search in metadata keys
 #'
-#' Using a character vector as query, this method tests whether all given keys 
-#' are present in the top-level names of the metadata (these may be nested, but 
-#' all sublists are ignored here). An empty query vector results in 
+#' Using a character vector as query, this method tests whether all given keys
+#' are present in the top-level names of the metadata (these may be nested, but
+#' all sublists are ignored here). An empty query vector results in
 #' \code{TRUE}. Note that the values of the character vector, not its names, if
 #' any, are used for querying the metadata.
 #' Using a list as query, this method tests whether all given keys are present
 #' in the names of the metadata.
-#' This works like the character method, but because a query list is given, the 
-#' comparison of keys can be applied recursively (by using, of course, a nested 
-#' query list). This is based on \code{\link{contains}} with the \code{values} 
+#' This works like the character method, but because a query list is given, the
+#' comparison of keys can be applied recursively (by using, of course, a nested
+#' query list). This is based on \code{\link{contains}} with the \code{values}
 #' argument set to \code{FALSE}.
 #'
 #' @name %k%
@@ -289,7 +297,7 @@ setGeneric("%k%", function(x, table) standardGeneric("%k%"))
 #~ @family getter-functions
 #' @keywords attribute
 #'
-#' @examples 
+#' @examples
 #'
 #' # The dataset contains the metadata keys 'Species' and 'Experiment' but
 #' # neither 'Trial' nor 'Organism' nor 'Run':
@@ -343,7 +351,7 @@ setGeneric("%K%", function(x, table) standardGeneric("%K%"))
 #' Using a character vector as query, this method tests whether a given key is
 #' present in the metadata and fetches an object that is not \code{NULL}. If
 #' the key has a length > 1, sublists are queried. An empty vector results in
-#' \code{TRUE}. Note that the values of the character vector, not its names, if 
+#' \code{TRUE}. Note that the values of the character vector, not its names, if
 #' any, are used for querying the metadata.
 #' Using a list as query, this function behaves like \code{\link{infix.k}}.
 #'
@@ -359,7 +367,7 @@ setGeneric("%K%", function(x, table) standardGeneric("%K%"))
 #~ @family getter-functions
 #' @keywords attribute
 #'
-#' @examples 
+#' @examples
 #'
 #' # The dataset contains the metadata keys 'Species' and 'Experiment' but
 #' # neither 'Trial' nor 'Organism' nor 'Run':
@@ -411,12 +419,12 @@ setGeneric("%q%", function(x, table) standardGeneric("%q%"))
 #' @aliases infix.q
 #' @rdname infix.q
 #'
-#' @param x Character vector or list used as query. 
+#' @param x Character vector or list used as query.
 #'   If a character vector, its \code{names} are used to select elements from
-#'   the top level of the metadata. These elements are then converted to 
-#'   \sQuote{character} mode before comparison with the values of \code{x}. A 
-#'   non-empty vector without a \code{names} attribute is accepted but will 
-#'   always yield \code{FALSE}. In contrast, an entirely empty vector yields 
+#'   the top level of the metadata. These elements are then converted to
+#'   \sQuote{character} mode before comparison with the values of \code{x}. A
+#'   non-empty vector without a \code{names} attribute is accepted but will
+#'   always yield \code{FALSE}. In contrast, an entirely empty vector yields
 #'   \code{TRUE}.
 #'   If a list, the comparison is applied recursively using
 #'   \code{\link{contains}} with the \code{values} argument set to \code{TRUE}
@@ -429,7 +437,7 @@ setGeneric("%q%", function(x, table) standardGeneric("%q%"))
 #~ @family getter-functions
 #' @keywords attribute
 #'
-#' @examples 
+#' @examples
 #'
 #' # The dataset contains the metadata keys 'Species' and 'Experiment' with the
 #' # values 'Escherichia coli' and 'First replicate':
@@ -444,7 +452,7 @@ setGeneric("%q%", function(x, table) standardGeneric("%q%"))
 #' stopifnot(!"Escherichia coli" %q% vaas_1)
 #' stopifnot(c(Species = "Escherichia coli") %q% vaas_1)
 #'
-#' stopifnot(c(Species = "Escherichia coli", 
+#' stopifnot(c(Species = "Escherichia coli",
 #'   Experiment = "First replicate") %q% vaas_1) # Combined query
 #'
 #' stopifnot(character() %q% vaas_1) # Empty query
@@ -453,9 +461,9 @@ setGeneric("%q%", function(x, table) standardGeneric("%q%"))
 #' stopifnot(list(Experiment = "First replicate") %q% vaas_1)
 #'
 #' # Choice among alternatives
-#' stopifnot(list(Experiment = c("First replicate", 
+#' stopifnot(list(Experiment = c("First replicate",
 #'   "Second replicate")) %q% vaas_1)
-#' stopifnot(!list(Experiment = c("Second replicate", 
+#' stopifnot(!list(Experiment = c("Second replicate",
 #'   "Third replicate")) %q% vaas_1)
 #'
 #' # Combined query together with choice among alternatives
@@ -465,8 +473,7 @@ setGeneric("%q%", function(x, table) standardGeneric("%q%"))
 #' stopifnot(list() %q% vaas_1) # Empty query
 #'
 setMethod("%q%", c("character", WMD), function(x, table) {
-  keys <- names(x)
-  if (length(keys) == 0L && length(x) > 0L)
+  if (length(keys <- names(x)) == 0L && length(x) > 0L)
     return(FALSE)
   all(x == sapply(table@metadata[keys], as.character))
 }, sealed = SEALED)
@@ -484,8 +491,8 @@ setMethod("%q%", c("list", WMD), function(x, table) {
 setGeneric("%Q%", function(x, table) standardGeneric("%Q%"))
 #' Query metadata (strict version)
 #'
-#' Using a character vector as query, test whether all given query keys are 
-#' present in the top-level names of the metadata and refer to the same query 
+#' Using a character vector as query, test whether all given query keys are
+#' present in the top-level names of the metadata and refer to the same query
 #' elements (without coercion to character).
 #' Using a list, conduct an exact query with this query list.
 #'
@@ -493,12 +500,12 @@ setGeneric("%Q%", function(x, table) standardGeneric("%Q%"))
 #' @aliases infix.largeq
 #' @rdname infix.largeq
 #'
-#' @param x Character vector or list used as query. 
-#'   If a character vector, the result is identical to the 
-#'   one of \code{\link{infix.q}} except for the fact that metadata elements 
+#' @param x Character vector or list used as query.
+#'   If a character vector, the result is identical to the
+#'   one of \code{\link{infix.q}} except for the fact that metadata elements
 #'   are not coerced to \sQuote{character} mode, making the query more strict.
-#'   If a list, the comparison is applied recursively 
-#'   using \code{\link{contains}} with the arguments \code{values} and 
+#'   If a list, the comparison is applied recursively
+#'   using \code{\link{contains}} with the arguments \code{values} and
 #'   \code{exact} set to \code{TRUE}. This might be too strict for most
 #'   applications. The main advantage of using a list over the character-based
 #'   search is that it allows one a nested query.
@@ -509,7 +516,7 @@ setGeneric("%Q%", function(x, table) standardGeneric("%Q%"))
 #~ @family getter-functions
 #' @keywords attribute
 #'
-#' @examples 
+#' @examples
 #'
 #' # The dataset contains the metadata keys 'Species' and 'Experiment' with the
 #' # values 'Escherichia coli' and 'First replicate':
@@ -524,7 +531,7 @@ setGeneric("%Q%", function(x, table) standardGeneric("%Q%"))
 #' stopifnot(c(`Plate number` = "6") %q% vaas_1)
 #'
 #' # Combined query
-#' stopifnot(c(Species = "Escherichia coli", 
+#' stopifnot(c(Species = "Escherichia coli",
 #'   Experiment = "First replicate") %Q% vaas_1)
 #'
 #' stopifnot(character() %Q% vaas_1) # Empty query
@@ -534,14 +541,13 @@ setGeneric("%Q%", function(x, table) standardGeneric("%Q%"))
 #'
 #' # Choice among alternatives is not done here: this query fails unless this
 #' # two-element vector is contained. Compare to %q%.
-#' stopifnot(!list(Experiment = c("First replicate", 
+#' stopifnot(!list(Experiment = c("First replicate",
 #'   "Second replicate")) %Q% vaas_1)
 #'
 #' stopifnot(list() %Q% vaas_1) # Empty query
 #'
 setMethod("%Q%", c("character", WMD), function(x, table) {
-  keys <- names(x)
-  if (length(keys) == 0L && length(x) > 0L)
+  if (length(keys <- names(x)) == 0L && length(x) > 0L)
     return(FALSE)
   all(sapply(keys, function(key) identical(x[[key]], table@metadata[[key]])))
 }, sealed = SEALED)
@@ -557,41 +563,40 @@ setMethod("%Q%", c("list", WMD), function(x, table) {
 ################################################################################
 #
 # Metadata mapping
-#  
+#
 
 
 setGeneric("map_metadata",
   function(object, mapping, ...) standardGeneric("map_metadata"))
 #' Map metadata
 #'
-#' Modify meta-information stored together with the measurements by using a 
-#' function (this is just a wrapper for \code{rapply}, with \code{how} set to 
+#' Modify meta-information stored together with the measurements by using a
+#' function (this is just a wrapper for \code{rapply}, with \code{how} set to
 #' \sQuote{replace}, if \code{values} is \code{TRUE}) or a \sQuote{character}
 #' vector-based mapping.
 #' The \code{\link{OPMS}} method applies this to all plates in turn
-#' and returns an \code{\link{OPMS}} object with accordingly modified 
+#' and returns an \code{\link{OPMS}} object with accordingly modified
 #' metadata.
 #'
 #' @param object \code{\link{WMD}} object or \code{\link{OPMS}} object.
 #' @param mapping A function. It is applied to all non-list elements of
 #'   \code{\link{metadata}}, which is traversed recursively. Alternatively, a
 #'   character vector. See \code{\link{map_values}} for usage
-#'   details. \code{\link{metadata_chars}} can be used to create a template 
+#'   details. \code{\link{metadata_chars}} can be used to create a template
 #'   for such a vector.
 #' @param values Logical scalar. If \code{FALSE}, metadata names, not values,
 #'   are mapped, and \code{classes} is ignored (names are always of class
 #'   \sQuote{character}).
-#' @param classes Character vector or (for the character vector-based mapping) 
-#'  \code{TRUE}. For the mapping with a function, this specifies the classes
-#'  that are mapped. For the mapping with a character vector, this specifies the
-#'  classes in addition to \sQuote{character} that are mapped (after converting
-#'  to \sQuote{character} mode). If \code{classes} is \code{TRUE}, 
-#'  \code{mapping} is treated as a mapping between class names, and the 
-#'  according conversions are applied. See the \code{coerce} argument of
-#'  \code{\link{map_values}} for details.
+#' @param classes Character vector or (for the character vector-based mapping)
+#'   \code{TRUE}. For the mapping with a function or vector, this specifies the
+#'   classes in addition to \sQuote{character} that are mapped (after
+#'   converting to \sQuote{character} mode). If \code{classes} is \code{TRUE},
+#'   \code{mapping} is treated as a mapping between class names, and the
+#'   according conversions are applied. See the \code{coerce} argument of
+#'   \code{\link{map_values}} for details.
 #' @param ... Optional argument passed to \code{mapping} if it is a function,
 #'   and from the \code{\link{OPMS}} method to the \code{\link{WMD}} method.
-#' @return \code{\link{WMD}} or \code{\link{OPMS}} object with modified 
+#' @return \code{\link{WMD}} or \code{\link{OPMS}} object with modified
 #'   metadata.
 #' @export
 #' @family metadata-functions
@@ -600,7 +605,7 @@ setGeneric("map_metadata",
 #'
 #' # WMD methods
 #' data(vaas_1)
-#' 
+#'
 #' # WMD+function method
 #' copy <- map_metadata(vaas_1, identity)
 #' stopifnot(identical(copy, vaas_1))
@@ -616,7 +621,7 @@ setGeneric("map_metadata",
 #' map["First replicate"] <- "Rep. 1"
 #' copy <- map_metadata(vaas_1, map)
 #' stopifnot(identical(names(metadata(copy)), names(metadata(vaas_1))))
-#' stopifnot(!identical(metadata(copy, "Experiment"), 
+#' stopifnot(!identical(metadata(copy, "Experiment"),
 #'   metadata(vaas_1, "Experiment")))
 #'
 #' # WMD+character method: mapping a name
@@ -647,11 +652,12 @@ setGeneric("map_metadata",
 #' y <- metadata(copy, "Experiment")
 #' stopifnot(y == "Rep. 1")
 #'
-setMethod("map_metadata", c(WMD, "function"), function(object, mapping, 
+setMethod("map_metadata", c(WMD, "function"), function(object, mapping,
     values = TRUE, classes = "ANY", ...) {
+  assert_length(values)
   object@metadata <- if (values)
-    rapply(object = object@metadata, f = mapping, classes = classes,
-       how = "replace", ...)
+    map_values(object = object@metadata, mapping = mapping, coerce = classes,
+      ...)
   else
     map_names(object = object@metadata, mapping = mapping, ...)
   object
@@ -661,6 +667,7 @@ setMethod("map_metadata", c(WMD, "function"), function(object, mapping,
 #'
 setMethod("map_metadata", c(WMD, "character"), function(object, mapping,
     values = TRUE, classes = "factor") {
+  assert_length(values)
   object@metadata <- if (values)
     map_values(object@metadata, mapping, coerce = classes)
   else
@@ -673,13 +680,13 @@ setMethod("map_metadata", c(WMD, "character"), function(object, mapping,
 ################################################################################
 #
 # Metadata characters
-#  
-  
+#
+
 setGeneric("metadata_chars",
   function(object, ...) standardGeneric("metadata_chars"))
 #' Get metadata characters
 #'
-#' Collect all \sQuote{character} entries from the meta-information stored 
+#' Collect all \sQuote{character} entries from the meta-information stored
 #' together with the measurements. Optionally coerce data of other types. The
 #' result can be used to create a mapping for \code{\link{map_metadata}}. The
 #' \code{\link{OPMS}} method just applies the \code{\link{WMD}} method to all
@@ -696,8 +703,8 @@ setGeneric("metadata_chars",
 #' @param ... Optional argument passed from the \code{\link{OPMS}} to the
 #'   \code{\link{WMD}} method.
 #' @return Character vector, sorted and made unique. Original \code{names}
-#'   attributes, if any, are dropped and replaced by the character vector 
-#'   itself. (This might be convenient regarding its use with 
+#'   attributes, if any, are dropped and replaced by the character vector
+#'   itself. (This might be convenient regarding its use with
 #'   \code{\link{map_metadata}}.)
 #' @export
 #' @family metadata-functions
@@ -718,18 +725,16 @@ setGeneric("metadata_chars",
 #' (y <- metadata_chars(vaas_4, values = FALSE)) # the keys
 #' stopifnot(length(x) > length(y))
 #'
-setMethod("metadata_chars", WMD, function(object, values = TRUE, 
+setMethod("metadata_chars", WMD, function(object, values = TRUE,
     classes = "factor") {
+  assert_length(values)
   if (values)
     map_values(object@metadata, coerce = classes)
   else
     map_names(object@metadata)
 }, sealed = SEALED)
-  
-  
-  
+
+
 ################################################################################
-  
-  
-  
+
 
